import type { Schema, Attribute } from '@strapi/strapi';

export interface SharedAddress extends Schema.Component {
  collectionName: 'components_shared_addresses';
  info: {
    displayName: 'address';
    icon: 'attachment';
    description: '';
  };
  attributes: {
    details: Attribute.String & Attribute.Required;
    district: Attribute.Relation<
      'shared.address',
      'oneToOne',
      'api::district.district'
    >;
    province: Attribute.Relation<
      'shared.address',
      'oneToOne',
      'api::province.province'
    >;
    commune: Attribute.Relation<
      'shared.address',
      'oneToOne',
      'api::commune.commune'
    >;
  };
}

export interface SharedCardItem extends Schema.Component {
  collectionName: 'components_shared_card_items';
  info: {
    displayName: 'cardItem';
    icon: 'archive';
  };
  attributes: {
    code: Attribute.String & Attribute.Required & Attribute.Unique;
    image: Attribute.Media & Attribute.Required;
  };
}

export interface SharedCustomerItem extends Schema.Component {
  collectionName: 'components_shared_customer_items';
  info: {
    displayName: 'customerItem';
    icon: 'command';
    description: '';
  };
  attributes: {
    name: Attribute.String;
    logo: Attribute.Media & Attribute.Required;
    link: Attribute.String;
  };
}

export interface SharedInfoItem extends Schema.Component {
  collectionName: 'components_shared_info_items';
  info: {
    displayName: 'infoItem';
    icon: 'cube';
    description: '';
  };
  attributes: {
    title: Attribute.String & Attribute.Required;
    content: Attribute.RichText &
      Attribute.Required &
      Attribute.CustomField<
        'plugin::ckeditor.CKEditor',
        {
          output: 'HTML';
          preset: 'rich';
        }
      >;
    slug: Attribute.String & Attribute.Required;
  };
}

export interface SharedMetaSocial extends Schema.Component {
  collectionName: 'components_shared_meta_socials';
  info: {
    displayName: 'metaSocial';
    icon: 'project-diagram';
  };
  attributes: {
    socialNetwork: Attribute.Enumeration<['Facebook', 'Twitter']> &
      Attribute.Required;
    title: Attribute.String &
      Attribute.Required &
      Attribute.SetMinMaxLength<{
        maxLength: 60;
      }>;
    description: Attribute.String &
      Attribute.Required &
      Attribute.SetMinMaxLength<{
        maxLength: 65;
      }>;
    image: Attribute.Media;
  };
}

export interface SharedOrderItem extends Schema.Component {
  collectionName: 'components_shared_order_items';
  info: {
    displayName: 'orderItem';
    icon: 'archive';
    description: '';
  };
  attributes: {
    product: Attribute.Relation<
      'shared.order-item',
      'oneToOne',
      'api::product.product'
    >;
    quantity: Attribute.Integer &
      Attribute.Required &
      Attribute.SetMinMax<
        {
          min: 1;
        },
        number
      > &
      Attribute.DefaultTo<1>;
    totalMoney: Attribute.Integer &
      Attribute.Required &
      Attribute.SetMinMax<
        {
          min: 0;
        },
        number
      > &
      Attribute.DefaultTo<0>;
    card: Attribute.Relation<'shared.order-item', 'oneToOne', 'api::card.card'>;
  };
}

export interface SharedSeo extends Schema.Component {
  collectionName: 'components_shared_seos';
  info: {
    displayName: 'seo';
    icon: 'search';
  };
  attributes: {
    metaTitle: Attribute.String &
      Attribute.Required &
      Attribute.SetMinMaxLength<{
        maxLength: 60;
      }>;
    metaDescription: Attribute.String &
      Attribute.Required &
      Attribute.SetMinMaxLength<{
        minLength: 50;
        maxLength: 160;
      }>;
    metaImage: Attribute.Media;
    metaSocial: Attribute.Component<'shared.meta-social', true>;
    keywords: Attribute.Text;
    metaRobots: Attribute.String;
    structuredData: Attribute.JSON;
    metaViewport: Attribute.String;
    canonicalURL: Attribute.String;
  };
}

export interface SharedVat extends Schema.Component {
  collectionName: 'components_shared_vats';
  info: {
    displayName: 'VAT';
    icon: 'expand';
    description: '';
  };
  attributes: {
    companyName: Attribute.String & Attribute.Required;
    taxCode: Attribute.String & Attribute.Required;
    emailReceive: Attribute.String & Attribute.Required;
    companyAddress: Attribute.String & Attribute.Required;
  };
}

declare module '@strapi/types' {
  export module Shared {
    export interface Components {
      'shared.address': SharedAddress;
      'shared.card-item': SharedCardItem;
      'shared.customer-item': SharedCustomerItem;
      'shared.info-item': SharedInfoItem;
      'shared.meta-social': SharedMetaSocial;
      'shared.order-item': SharedOrderItem;
      'shared.seo': SharedSeo;
      'shared.vat': SharedVat;
    }
  }
}
